How to send Newsletters with django-campaign — django-campaign 0.3.0-pre documentation

### Navigation

- index
- next |
- previous |
- django-campaign 0.3.0-pre documentation »

# How to send Newsletters with django-campaign

Here is a very brief overview how to use django-campaign:

- If you plan to send out different Newsletters to different SusbcriberLists, it might be a good idea to create a Newsletter objects through the Django Admin.
- Setup one or more SubscriberList objects in the Django Admin interface or programmatically.
- Create at least one MailTemplate object through the Django Admin or programmatically.
- Create a Campaign object and assign the corresponding MailTemplate object, one or more SubscriberLists.
- Send the Campaign through the Django Admin or programmatically.

### Navigation

- index
- next |
- previous |
- django-campaign 0.3.0-pre documentation »